@@ -1,7 +1,7 @@
 from datetime import datetime
-from logging import DEBUG, StreamHandler, INFO, Formatter, Logger
+from logging import DEBUG, INFO, Formatter, Logger, StreamHandler
 from logging.handlers import RotatingFileHandler
-from os import path
+from pathlib import Path
 from tempfile import gettempdir
 
 
@@ -13,12 +13,13 @@ def config_logger(logger: Logger, verbose=False) -> None:
     :param verbose: turn on/off verbose mode
     """
     logger.setLevel(DEBUG)
-    file_hand = RotatingFileHandler(filename=path.join(gettempdir(), 'dcspy.log'), mode='a', encoding='utf-8', maxBytes=5 * 1024 * 1024, backupCount=1)
-    file_hand.setLevel(DEBUG)
+    file_hand = RotatingFileHandler(filename=Path(gettempdir()) / 'dcspy.log', mode='a', encoding='utf-8', maxBytes=5 * 1024 * 1024, backupCount=1)
     file_hand.setFormatter(Formatter('%(asctime)s | %(name)-17s | %(levelname)-7s | %(threadName)-10s | %(message)s / %(funcName)s:%(lineno)d'))
+    file_hand.setLevel(INFO)
     stream_hand = StreamHandler()
     stream_hand.setLevel(INFO)
     if verbose:
+        file_hand.setLevel(DEBUG)
         stream_hand.setLevel(DEBUG)
     stream_hand.setFormatter(Formatter('%(levelname)-7s | %(message)s'))
     logger.addHandler(stream_hand)
