@@ -7,7 +7,7 @@ from typing import List
 
 from PIL import Image, ImageDraw
 
-from dcspy import LcdColor, LcdMono, SUPPORTED_CRAFTS, SEND_ADDR, LcdButton
+from dcspy import SEND_ADDR, SUPPORTED_CRAFTS, LcdButton, LcdColor, LcdMono
 from dcspy.aircraft import Aircraft
 from dcspy.dcsbios import ProtocolParser
 from dcspy.sdk import lcd_sdk
@@ -16,9 +16,10 @@ LOG = getLogger(__name__)
 
 
 class LogitechKeyboard:
-    def __init__(self, parser_hook: ProtocolParser, **kwargs) -> None:
+    """General keyboard with LCD from Logitech."""
+    def __init__(self, parser: ProtocolParser, **kwargs) -> None:
         """
-        General keyboard with LCD form Logitech.
+        General keyboard with LCD from Logitech.
 
         It can be easily extended for any of:
         - Mono LCD: G13, G15 (v1 and v2) and G510
@@ -30,13 +31,13 @@ class LogitechKeyboard:
         - send button request to DCS-BIOS
 
         Child class needs redefine:
-        - buttons with supported buttons as tuple of int
         - pass lcd_type argument as LcdInfo to super constructor
 
-        :param parser_hook: BSC-BIOS parser
+        :param parser: DCS-BIOS parser instance
         """
-        getattr(import_module('dcspy.dcsbios'), 'StringBuffer')(parser_hook, 0x0000, 16, partial(self.detecting_plane))
-        self.parser = parser_hook
+        detect_plane = {'parser': parser, 'address': 0x0, 'max_length': 0x10, 'callback': partial(self.detecting_plane)}
+        getattr(import_module('dcspy.dcsbios'), 'StringBuffer')(**detect_plane)
+        self.parser = parser
         self.plane_name = ''
         self.plane_detected = False
         self.already_pressed = False
@@ -65,8 +66,7 @@ class LogitechKeyboard:
         :param message: List of strings to display, row by row.
         """
         self._display = message
-        img = self._prepare_image()
-        lcd_sdk.update_display(img)
+        lcd_sdk.update_display(self._prepare_image())
 
     @staticmethod
     def text(message: List[str]) -> None:
@@ -85,15 +85,14 @@ class LogitechKeyboard:
 
         :param value: data from DCS-BIOS
         """
-        value = value.replace('-', '').replace('_', '')
-        if self.plane_name != value:
-            self.plane_name = value
+        short_name = value.replace('-', '').replace('_', '')
+        if self.plane_name != short_name:
+            self.plane_name = short_name
             if self.plane_name in SUPPORTED_CRAFTS:
-                self.plane_name = value
                 LOG.info(f'Detected Aircraft: {value}')
-                self.display = ['Detected aircraft:', self.plane_name]
+                self.display = ['Detected aircraft:', SUPPORTED_CRAFTS[self.plane_name]['name']]
                 self.plane_detected = True
-            else:
+            elif self.plane_name not in SUPPORTED_CRAFTS and self.plane_name:
                 LOG.warning(f'Not supported aircraft: {value}')
                 self.display = ['Detected aircraft:', self.plane_name, 'Not supported yet!']
 
@@ -105,11 +104,11 @@ class LogitechKeyboard:
         """
         self.plane_detected = False
         self.plane = getattr(import_module('dcspy.aircraft'), self.plane_name)(self.lcd)
-        LOG.debug(f'Dynamic load of: {self.plane_name} as {SUPPORTED_CRAFTS[self.plane_name]}')
+        LOG.debug(f'Dynamic load of: {self.plane_name} as {SUPPORTED_CRAFTS[self.plane_name]["name"]}')
         LOG.debug(f'{repr(self)}')
         for field_name, proto_data in self.plane.bios_data.items():
-            buffer = getattr(import_module('dcspy.dcsbios'), proto_data['class'])
-            buffer(parser=self.parser, callback=partial(self.plane.set_bios, field_name), **proto_data['args'])
+            dcsbios_buffer = getattr(import_module('dcspy.dcsbios'), proto_data['klass'])
+            dcsbios_buffer(parser=self.parser, callback=partial(self.plane.set_bios, field_name), **proto_data['args'])
 
     def check_buttons(self) -> LcdButton:
         """
@@ -139,7 +138,7 @@ class LogitechKeyboard:
         if button.value:
             sock.sendto(bytes(self.plane.button_request(button), 'utf-8'), SEND_ADDR)
 
-    def clear(self, true_clear=False):
+    def clear(self, true_clear=False) -> None:
         """
         Clear LCD.
 
@@ -156,38 +155,50 @@ class LogitechKeyboard:
         For G19 takes first 8 or fewer elements of list and display as 8 rows.
         :return: image instance ready display on LCD
         """
-        img = Image.new(mode=self.lcd.mode, size=(self.lcd.width, self.lcd.height), color=self.lcd.background)
+        img = Image.new(mode=self.lcd.mode.value, size=(self.lcd.width, self.lcd.height), color=self.lcd.background)
         draw = ImageDraw.Draw(img)
         for line_no, line in enumerate(self._display):
             draw.text(xy=(0, self.vert_space * line_no), text=line, fill=self.lcd.foreground, font=self.lcd.font_s)
         return img
 
-    def __str__(self):
+    def __str__(self) -> str:
+        """
+        Show basic info of LCD.
+
+        :return: string
+        """
         return f'{self.__class__.__name__}: {self.lcd.width}x{self.lcd.height}'
 
-    def __repr__(self):
+    def __repr__(self) -> str:
+        """
+        Show all details of LCD.
+
+        :return: string
+        """
         return f'{super().__repr__()} with: {pformat(self.__dict__)}'
 
 
 class KeyboardMono(LogitechKeyboard):
-    def __init__(self, parser_hook: ProtocolParser) -> None:
+    """Logitech`s keyboard with mono LCD."""
+    def __init__(self, parser: ProtocolParser) -> None:
         """
         Logitech`s keyboard with mono LCD.
 
         Support for: G510, G13, G15 (v1 and v2)
-        :param parser_hook: BSC-BIOS parser
+        :param parser: DCS-BIOS parser instance
         """
-        super().__init__(parser_hook, lcd_type=LcdMono)
+        super().__init__(parser, lcd_type=LcdMono)
         self.vert_space = 10
 
 
 class KeyboardColor(LogitechKeyboard):
-    def __init__(self, parser_hook: ProtocolParser) -> None:
+    """Logitech`s keyboard with color LCD."""
+    def __init__(self, parser: ProtocolParser) -> None:
         """
         Logitech`s keyboard with color LCD.
 
         Support for: G19
-        :param parser_hook: BSC-BIOS parser
+        :param parser: DCS-BIOS parser instance
         """
-        super().__init__(parser_hook, lcd_type=LcdColor)
+        super().__init__(parser, lcd_type=LcdColor)
         self.vert_space = 40
