@@ -1,4 +1,4 @@
-from ctypes import CDLL, sizeof, c_void_p
+from ctypes import CDLL, c_void_p, sizeof
 from logging import getLogger
 from os import environ
 from platform import architecture
@@ -10,7 +10,7 @@ LOG = getLogger(__name__)
 
 def _init_dll(lib_type: str) -> CDLL:
     """
-    Initialization of C dynamic linking library.
+    Initialize C dynamic linking library.
 
     :param lib_type: LCD or LED
     :return: C DLL instance
@@ -20,12 +20,14 @@ def _init_dll(lib_type: str) -> CDLL:
         prog_files = environ['PROGRAMW6432']
     except KeyError:
         prog_files = environ['PROGRAMFILES']
-    return CDLL(f"{prog_files}\\Logitech Gaming Software\\SDK\\{lib_type}\\{arch}\\Logitech{lib_type.capitalize()}.dll")
+    dll_path = f"{prog_files}\\Logitech Gaming Software\\SDK\\{lib_type}\\{arch}\\Logitech{lib_type.capitalize()}.dll"
+    LOG.debug(f'Selected DLL: {dll_path}')
+    return CDLL(dll_path)
 
 
 def load_dll(lib_type: str) -> Optional[CDLL]:
     """
-    Initialization and loading of C dynamic linking library.
+    Initialize and load of C dynamic linking library.
 
     :param lib_type: library to load: LCD or LED
     :return: C DLL instance
@@ -35,9 +37,9 @@ def load_dll(lib_type: str) -> Optional[CDLL]:
         LOG.info(f'Loading of {lib_type} SDK success')
         return dll
     except (KeyError, FileNotFoundError) as err:
-        header = '*' * 40
-        space = ' ' * 15
-        LOG.error(f'\n{header}\n*{space}ERROR!!!{space}*\n{header}\n'
+        header = '*' * 44
+        error_string = 'ERROR!!!'
+        LOG.error(f'\n{header}\n*{error_string:^42}*\n{header}\n'
                   f'Loading of {lib_type} SDK failed: {err.__class__.__name__}', exc_info=True)
-        LOG.error(f'\n{header}')
+        LOG.error(f'{header}')
         return None
